# parallel build broken
%global _smp_mflags -j1
%global __requires_exclude_from ^%{_docdir}/.*$
%global __provides_exclude_from ^%{python3_sitearch}/.*\\.so$

%bcond_with java

Summary:        Reference implementation of OGC KML 2.2
Name:           libkml
Version:        1.3.0
Release:        5%{?dist}
License:        BSD
URL:            https://github.com/libkml/libkml
Source0:        %{url}/archive/%{version}/libkml-%{version}.tar.gz
# obtaining method: wget -O minizip-1.3.0.tar.gz http://sourceforge.net/projects/libkml-files/files/1.3.0/minizip.tar.gz/download
Source1:        minizip-1.3.0.tar.gz
# see https://github.com/libkml/libkml/pull/239
Patch3000:      0001-Fix-build-failure-due-to-failure-to-convert-pointer-.patch
Patch3001:      0002-Fix-mistaken-use-of-std-cerr-instead-of-std-endl.patch
Patch3002:      0003-Fix-python-tests.patch
Patch3003:      0004-Correctly-build-and-run-java-test.patch
# not compile python sources during build until rpmbuild
Patch3004:      libkml_dont-bytecompile.patch
# add crypt.h
Patch3005:      libkml_crypth.patch
# add local file for bundled minizip
Patch3006:      libkml-bundle-minizip.patch
# fix OOB array access that could occur in strcmp because of the undersized array
Patch3007:      libkml_test_strcmp.patch

BuildRequires:  make cmake gcc-c++
BuildRequires:  curl-devel boost-devel expat-devel gtest-devel
BuildRequires:  python3-devel swig uriparser-devel zlib-devel
%if %{with java}
BuildRequires:  java-devel junit
%endif
Provides:       bundled(minizip) = 1.3.0


%description
This is Google's reference implementation of OGC KML 2.2. It also includes implementations 
of Google's gx: extensions used by Google Earth, as well as several utility libraries for 
working with other formats.


%package -n python3-%{name}
Summary:        Python 3 bindings for %{name}
Requires:       %{name} = %{version}-%{release}

%description -n python3-%{name}
This package provides Python 3 bindings for %{name}.


%if %{with java}
%package java
Summary:        Java bindings for %{name}
Requires:       %{name} = %{version}-%{release}

%description java
Tis package provides Java bindings for %{name}.
%endif


%package        devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release}
Requires:       boost-devel
Requires:       expat-devel

%description    devel
This package provides libraries and header files for developing applications that use %{name}.


%prep
%autosetup -p1 -a1


%build
pushd minizip
%cmake -DBUILD_SHARED_LIBS=OFF
%cmake_build
popd

%cmake -DWITH_SWIG=ON -DWITH_PYTHON=ON \
%if %{with java}
  -DWITH_JAVA=ON -DJNI_INSTALL_DIR=%{_libdir}/%{name} \
%endif
  -DCMAKE_INSTALL_DIR=%{_libdir}/cmake/%{name} \
  -DINCLUDE_INSTALL_DIR=%{_includedir}/kml \
  -DPYTHON_LIBRARY=%{_libdir}/libpython%{python3_version}$(python3-config --abiflags).so \
  -DPYTHON_INCLUDE_DIR=%{_includedir}/python%{python3_version}$(python3-config --abiflags)/ \
  -DPYTHON_INSTALL_DIR=%{python3_sitearch} \
  -DMINIZIP_INCLUDE_DIR=$PWD -DMINIZIP_LIBRARY=$PWD/minizip/%{_vpath_builddir}/libminizip.a \
  -DBUILD_TESTING=ON \
  -DBUILD_EXAMPLES=ON
%cmake_build


%install
%cmake_install


%check
%ctest


%files
%license LICENSE
%doc AUTHORS README.md
%{_libdir}/libkml*.so.*

%files -n python3-%{name}
%{python3_sitearch}/*.so
%{python3_sitearch}/*.py
%{python3_sitearch}/__pycache__/*.pyc

%if %{with java}
%files java
%{_javadir}/LibKML.jar
%{_libdir}/%{name}/
%endif

%files devel
%doc examples
%{_includedir}/kml/
%{_libdir}/libkml*.so
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/cmake/%{name}/


%changelog
* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.3.0-5
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.3.0-4
- Rebuilt for OpenCloudOS Stream 23.09

* Tue Aug 01 2023 rockerzhu rockerzhu@tencent.com - 1.3.0-3
- Rebuilt for boost 1.82.0

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.3.0-2
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Apr 21 2023 Wang Guodong <gordonwwang@tencent.com> - 1.3.0-1
- initial build
